package fr.sanchezm.attestationsCovid19.ui.attestations

import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import fr.sanchezm.attestationsCovid19.R
import fr.sanchezm.attestationsCovid19.data.db.entity.Attestation
import fr.sanchezm.attestationsCovid19.interfaces.ItemClickListener
import kotlinx.android.synthetic.main.attestation_item.view.*

class AttestationsAdapter(
    private val items: ArrayList<Attestation>,
    private val itemClickListener: ItemClickListener
) : RecyclerView.Adapter<AttestationsAdapter.ViewHolder>() {

    override fun getItemCount(): Int {
        return items.size
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder = ViewHolder(
        LayoutInflater.from(parent.context).inflate(R.layout.attestation_item, parent, false),
        itemClickListener
    )

    override fun onBindViewHolder(holder: ViewHolder, position: Int) {
        holder.bind(items[(items.size - 1) - position])
    }

    fun updateAttestations(attestations: List<Attestation>) {
        items.clear()
        items.addAll(attestations)
        notifyDataSetChanged()
    }

    class ViewHolder(private var view: View, private val itemClickListener: ItemClickListener) :
        RecyclerView.ViewHolder(view) {

        private val peopleItem = view.people_item_data
        private val dateItem = view.date_item_data
        private val reasonItem = view.reason_item_data

        fun bind(attestation: Attestation) {
            peopleItem.text = attestation.getNameFormatted()
            dateItem.text = attestation.getExitDateFormatted()
            reasonItem.text = attestation.getMotifsFormatted()
            view.setOnClickListener { itemClickListener.onItemClick(attestation) }
        }
    }
}